eolib.protocol¶
EO protocol data structures.
- class ProtocolEnumMeta[source]¶
Bases:
EnumTypeEnum metaclass that preserves unrecognized values as synthetic enum members.
- exception SerializationError[source]¶
Bases:
ExceptionRepresents an error in serializing a protocol data structure.
- class AdminLevel[source]¶
Bases:
IntEnumThe admin level of a player
- Player = 0¶
- Spy = 1¶
- LightGuide = 2¶
- Guardian = 3¶
- GameMaster = 4¶
- HighGameMaster = 5¶
- class Coords[source]¶
Bases:
objectMap coordinates
- class Direction[source]¶
Bases:
IntEnumThe direction a player or NPC is facing
- Down = 0¶
- Left = 1¶
- Up = 2¶
- Right = 3¶
- class Emote[source]¶
Bases:
IntEnumEmote that can be played over a player’s head
- Happy = 1¶
- Depressed = 2¶
- Sad = 3¶
- Angry = 4¶
- Confused = 5¶
- Surprised = 6¶
- Hearts = 7¶
- Moon = 8¶
- Suicidal = 9¶
- Embarrassed = 10¶
- Drunk = 11¶
- Trade = 12¶
- LevelUp = 13¶
- Playful = 14¶