eolib.protocol.pub¶
EO pub file data structures.
- class Ecf[source]¶
Bases:
objectEndless Class File
- class EcfRecord[source]¶
Bases:
objectRecord of Class data in an Endless Class File
- __init__(*, name, parent_type, stat_group, str, intl, wis, agi, con, cha)[source]¶
Create a new instance of EcfRecord.
- Parameters:
name (
str) – (Length must be 252 or less.)parent_type (
int) – (Value range is 0-252.)stat_group (
int) – (Value range is 0-252.)str (
int) – (Value range is 0-64008.)intl (
int) – (Value range is 0-64008.)wis (
int) – (Value range is 0-64008.)agi (
int) – (Value range is 0-64008.)con (
int) – (Value range is 0-64008.)cha (
int) – (Value range is 0-64008.)
- class Eif[source]¶
Bases:
objectEndless Item File
- class EifRecord[source]¶
Bases:
objectRecord of Item data in an Endless Item File
- __init__(*, name, graphic_id, type, subtype, special, hp, tp, min_damage, max_damage, accuracy, evade, armor, return_damage, str, intl, wis, agi, con, cha, light_resistance, dark_resistance, earth_resistance, air_resistance, water_resistance, fire_resistance, spec1, spec2, spec3, level_requirement, class_requirement, str_requirement, int_requirement, wis_requirement, agi_requirement, con_requirement, cha_requirement, element, element_damage, weight, size)[source]¶
Create a new instance of EifRecord.
- Parameters:
name (
str) – (Length must be 252 or less.)graphic_id (
int) – (Value range is 0-64008.)type (
ItemType)subtype (
ItemSubtype)special (
ItemSpecial)hp (
int) – (Value range is 0-64008.)tp (
int) – (Value range is 0-64008.)min_damage (
int) – (Value range is 0-64008.)max_damage (
int) – (Value range is 0-64008.)accuracy (
int) – (Value range is 0-64008.)evade (
int) – (Value range is 0-64008.)armor (
int) – (Value range is 0-64008.)return_damage (
int) – (Value range is 0-252.)str (
int) – (Value range is 0-252.)intl (
int) – (Value range is 0-252.)wis (
int) – (Value range is 0-252.)agi (
int) – (Value range is 0-252.)con (
int) – (Value range is 0-252.)cha (
int) – (Value range is 0-252.)light_resistance (
int) – (Value range is 0-252.)dark_resistance (
int) – (Value range is 0-252.)earth_resistance (
int) – (Value range is 0-252.)air_resistance (
int) – (Value range is 0-252.)water_resistance (
int) – (Value range is 0-252.)fire_resistance (
int) – (Value range is 0-252.)spec1 (
int) – Holds one the following values, depending on item type: scroll_map, doll_graphic, exp_reward, hair_color, effect, key, alcohol_potency (Value range is 0-16194276.)spec2 (
int) – Holds one the following values, depending on item type: scroll_x, gender (Value range is 0-252.)spec3 (
int) – Holds one the following values, depending on item type: scroll_y (Value range is 0-252.)level_requirement (
int) – (Value range is 0-64008.)class_requirement (
int) – (Value range is 0-64008.)str_requirement (
int) – (Value range is 0-64008.)int_requirement (
int) – (Value range is 0-64008.)wis_requirement (
int) – (Value range is 0-64008.)agi_requirement (
int) – (Value range is 0-64008.)con_requirement (
int) – (Value range is 0-64008.)cha_requirement (
int) – (Value range is 0-64008.)element (
Element)element_damage (
int) – (Value range is 0-252.)weight (
int) – (Value range is 0-252.)size (
ItemSize)
- property subtype: ItemSubtype¶
The subtype field.
- property special: ItemSpecial¶
The special field.
- property spec1: int¶
Holds one the following values, depending on item type: scroll_map, doll_graphic, exp_reward, hair_color, effect, key, alcohol_potency
- class Element[source]¶
Bases:
IntEnum- None_ = 0¶
- Light = 1¶
- Dark = 2¶
- Earth = 3¶
- Wind = 4¶
- Water = 5¶
- Fire = 6¶
- class Enf[source]¶
Bases:
objectEndless NPC File
- class EnfRecord[source]¶
Bases:
objectRecord of NPC data in an Endless NPC File
- __init__(*, name, graphic_id, race, boss, child, type, behavior_id, hp, tp, min_damage, max_damage, accuracy, evade, armor, return_damage, element, element_damage, element_weakness, element_weakness_damage, level, experience)[source]¶
Create a new instance of EnfRecord.
- Parameters:
name (
str) – (Length must be 252 or less.)graphic_id (
int) – (Value range is 0-64008.)race (
int) – (Value range is 0-252.)boss (
bool)child (
bool)type (
NpcType)behavior_id (
int) – (Value range is 0-64008.)hp (
int) – (Value range is 0-16194276.)tp (
int) – (Value range is 0-64008.)min_damage (
int) – (Value range is 0-64008.)max_damage (
int) – (Value range is 0-64008.)accuracy (
int) – (Value range is 0-64008.)evade (
int) – (Value range is 0-64008.)armor (
int) – (Value range is 0-64008.)return_damage (
int) – (Value range is 0-252.)element (
Element)element_damage (
int) – (Value range is 0-64008.)element_weakness (
Element)element_weakness_damage (
int) – (Value range is 0-64008.)level (
int) – (Value range is 0-252.)experience (
int) – (Value range is 0-16194276.)
- class Esf[source]¶
Bases:
objectEndless Skill File
- class EsfRecord[source]¶
Bases:
objectRecord of Skill data in an Endless Skill File
- __init__(*, name, chant, icon_id, graphic_id, tp_cost, sp_cost, cast_time, nature, type, element, element_power, target_restrict, target_type, target_time, max_skill_level, min_damage, max_damage, accuracy, evade, armor, return_damage, hp_heal, tp_heal, sp_heal, str, intl, wis, agi, con, cha)[source]¶
Create a new instance of EsfRecord.
- Parameters:
name (
str) – (Length must be 252 or less.)chant (
str) – (Length must be 252 or less.)icon_id (
int) – (Value range is 0-64008.)graphic_id (
int) – (Value range is 0-64008.)tp_cost (
int) – (Value range is 0-64008.)sp_cost (
int) – (Value range is 0-64008.)cast_time (
int) – (Value range is 0-252.)nature (
SkillNature)type (
SkillType)element (
Element)element_power (
int) – (Value range is 0-64008.)target_restrict (
SkillTargetRestrict)target_type (
SkillTargetType)target_time (
int) – (Value range is 0-252.)max_skill_level (
int) – (Value range is 0-64008.)min_damage (
int) – (Value range is 0-64008.)max_damage (
int) – (Value range is 0-64008.)accuracy (
int) – (Value range is 0-64008.)evade (
int) – (Value range is 0-64008.)armor (
int) – (Value range is 0-64008.)return_damage (
int) – (Value range is 0-252.)hp_heal (
int) – (Value range is 0-64008.)tp_heal (
int) – (Value range is 0-64008.)sp_heal (
int) – (Value range is 0-252.)str (
int) – (Value range is 0-64008.)intl (
int) – (Value range is 0-64008.)wis (
int) – (Value range is 0-64008.)agi (
int) – (Value range is 0-64008.)con (
int) – (Value range is 0-64008.)cha (
int) – (Value range is 0-64008.)
- property nature: SkillNature¶
The nature field.
- property target_restrict: SkillTargetRestrict¶
The target_restrict field.
- property target_type: SkillTargetType¶
The target_type field.
- class ItemSize[source]¶
Bases:
IntEnumSize of an item in the inventory
- Size1x1 = 0¶
- Size1x2 = 1¶
- Size1x3 = 2¶
- Size1x4 = 3¶
- Size2x1 = 4¶
- Size2x2 = 5¶
- Size2x3 = 6¶
- Size2x4 = 7¶
- class ItemSpecial[source]¶
Bases:
IntEnum- Normal = 0¶
- Rare = 1¶
- Legendary = 2¶
- Unique = 3¶
- Lore = 4¶
- Cursed = 5¶
- class ItemSubtype[source]¶
Bases:
IntEnum- None_ = 0¶
- Ranged = 1¶
- Arrows = 2¶
- Wings = 3¶
- Reserved4 = 4¶
- class ItemType[source]¶
Bases:
IntEnum- General = 0¶
- Reserved1 = 1¶
- Currency = 2¶
- Heal = 3¶
- Teleport = 4¶
- Reserved5 = 5¶
- ExpReward = 6¶
- Reserved7 = 7¶
- Reserved8 = 8¶
- Key = 9¶
- Weapon = 10¶
- Shield = 11¶
- Armor = 12¶
- Hat = 13¶
- Boots = 14¶
- Gloves = 15¶
- Accessory = 16¶
- Belt = 17¶
- Necklace = 18¶
- Ring = 19¶
- Armlet = 20¶
- Bracer = 21¶
- Alcohol = 22¶
- EffectPotion = 23¶
- HairDye = 24¶
- CureCurse = 25¶
- Reserved26 = 26¶
- Reserved27 = 27¶
- Reserved28 = 28¶
- Reserved29 = 29¶
- class NpcType[source]¶
Bases:
IntEnum- Friendly = 0¶
- Passive = 1¶
- Aggressive = 2¶
- Reserved3 = 3¶
- Reserved4 = 4¶
- Reserved5 = 5¶
- Shop = 6¶
- Inn = 7¶
- Reserved8 = 8¶
- Bank = 9¶
- Barber = 10¶
- Guild = 11¶
- Priest = 12¶
- Lawyer = 13¶
- Trainer = 14¶
- Quest = 15¶